The km3py metaproject is a collection of KM3NeT Python packages.
================================================================

.. image:: https://examples.pages.km3net.de/km3badges/docs-latest-brightgreen.svg
    :target: https://km3py.pages.km3net.de/km3py


This package includes:

- km3pipe
- km3io
- km3astro
- km3db
- km3net-testdata
- km3flux
